Struct feature_check::defs::Config [−][src]
pub struct Config {
pub option_name: String,
pub prefix: String,
pub program: String,
pub mode: Mode,
}Expand description
Runtime configuration settings for
the obtain_features function.
Fields
option_name: StringThe option to pass to the program to query for supported features.
prefix: StringThe prefix to look for in the lines output by the program.
program: StringThe name or full path of the program to execute.
mode: ModeThe feature-check tool’s operating mode.