Trait feature_check::expr::Calculable[][src]

pub trait Calculable: Debug {
    fn get_value(
        &self,
        features: &HashMap<String, String>
    ) -> Result<CalcResult, Box<dyn Error>>; }
An object that may be evaluated and provide a result.

Required methods

Get the value of the evaluated term or expression as applied to the list of features obtained for the program.

Implementors